#
# spec file for package ghc-primitive
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name primitive
Name:           ghc-%{pkg_name}
Version:        0.6.4.0
Release:        lp151.1.2
Summary:        Primitive memory-related operations
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel

%description
This package provides various primitive memory-related operations.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc changelog.md

%changelog
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update primitive to version 0.6.4.0.
  [#]# Changes in version 0.6.4.0
  * Introduce `Data.Primitive.PrimArray`, which offers types and function
    for dealing with a `ByteArray` tagged with a phantom type variable for
    tracking the element type.
  * Implement `isByteArrayPinned` and `isMutableByteArrayPinned`.
  * Add `Eq1`, `Ord1`, `Show1`, and `Read1` instances for `Array` and
    `SmallArray`.
  * Improve the test suite. This includes having property tests for
    typeclasses from `base` such as `Eq`, `Ord`, `Functor`, `Applicative`,
    `Monad`, `IsList`, `Monoid`, `Foldable`, and `Traversable`.
  * Fix the broken `IsList` instance for `ByteArray`. The old definition
    would allocate a byte array of the correct size and then leave the
    memory unitialized instead of writing the list elements to it.
  * Fix the broken `Functor` instance for `Array`. The old definition
    would allocate an array of the correct size with thunks for erroring
    installed at every index. It failed to replace these thunks with
    the result of the function applied to the elements of the argument array.
  * Fix the broken `Applicative` instances of `Array` and `SmallArray`.
    The old implementation of `<*>` for `Array` failed to initialize
    some elements but correctly initialized others in the resulting
    `Array`. It is unclear what the old behavior of `<*>` was for
    `SmallArray`, but it was incorrect.
  * Fix the broken `Monad` instances for `Array` and `SmallArray`.
  * Fix the implementation of `foldl1` in the `Foldable` instances for
    `Array` and `SmallArray`. In both cases, the old implementation
    simply returned the first element of the array and made no use of
    the other elements in the array.
  * Fix the implementation of `mconcat` in the `Monoid` instance for
    `SmallArray`.
  * Implement `Data.Primitive.Ptr`, implementations of `Ptr` functions
    that require a `Prim` constraint instead of a `Storable` constraint.
  * Add `PrimUnlifted` instances for `TVar` and `MVar`.
  * Use `compareByteArrays#` for the `Eq` and `Ord` instances of
    `ByteArray` when building with GHC 8.4 and newer.
  * Add `Prim` instances for lots of types in `Foreign.C.Types` and
    `System.Posix.Types`.
  * Reexport `Data.Primitive.SmallArray` and `Data.Primitive.UnliftedArray`
    from `Data.Primitive`.
  * Add fold functions and map function to `Data.Primitive.UnliftedArray`.
    Add typeclass instances for `IsList`, `Ord`, and `Show`.
  * Add `defaultSetByteArray#` and `defaultSetOffAddr#` to
    `Data.Primitive.Types`.
* Mon May 14 2018 psimons@suse.com
- Update primitive to version 0.6.3.0.
  * Add `PrimMonad` instances for `ContT`, `AccumT`, and `SelectT` from
    `transformers`
  * Add `Eq`, `Ord`, `Show`, and `IsList` instances for `ByteArray`
  * Add `Semigroup` instances for `Array` and `SmallArray`. This allows
    `primitive` to build on GHC 8.4 and later.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.6.2.0 revision 1.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6.1.0 revision 1 with cabal2obs.
* Sun Sep 27 2015 mimi.vx@gmail.com
- update to 0.6.1.0
  * Use more appropriate types in internal memset functions, which prevents
    overflows/segfaults on 64-bit systems.
  * Fixed a warning on GHC 7.10
  * Worked around a -dcore-lint bug in GHC 7.6/7.7
* Thu Apr  9 2015 mimi.vx@gmail.com
- update to 0.6
  + Split PrimMonad into two classes to allow automatic lifting of primitive
    operations into monad transformers. The internal operation has moved
    to the PrimBase class.
  + Fixed the test suite on older GHCs
  + Changed primitive_ to work around an oddity with GHC's code generation on
    certain versions that led to side effects not happening when used in
    conjunction with certain very unsafe IO performers.
  + Allow primitive to build on GHC 7.9
  + Implement cloneArray and cloneMutableArray primitives
    (with fall-back implementations for GHCs prior to version 7.2.1)
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- update to 0.5.2.1 for Haskell Platform 2014.2.0.0
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- more transparent packaging (fewer macros)
* Sun Dec 30 2012 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Wed Oct 17 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.0.1 for Haskell Platform 2012.4.0.0 RC2
* Tue Oct  2 2012 peter.trommler@ohm-hochschule.de
- update to 0.5 from upstream
- required by ghc-vector 0.10 as part of Haskell Platform 2012.4.0.0
* Fri Jun  8 2012 peter.trommler@ohm-hochschule.de
- use cabal2spec 0.25.5 spec file template
* Thu Jan 19 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
